Acquia Cloud Site Factory Connector
===================================

[![Build Status](https://core.cloudbees.ais.acquia.io/devops-pipeline-jenkins/buildStatus/icon?job=ACSF-acsf-Pipeline-PIPELINE%2Fmaster)](https://core.cloudbees.ais.acquia.io/devops-pipeline-jenkins/job/ACSF-acsf-Pipeline-PIPELINE/job/master/)

[Acquia Cloud Site Factory](http://www.acquia.com/products-services/acquia-cloud-site-factory)
provides an environment and a robust set of tools that simplify management of
many Drupal sites, allowing you to quickly deliver and manage any number of
websites.

This set of modules provides the necessary integrations for a Drupal site to
function on the Acquia Cloud Site Factory platform.

This text provides some technical background on assorted topics. More user
facing documentation is available at https://docs.acquia.com/site-factory/module/.


Dependencies / standalone and interconnected modules
----------------------------------------------------

One module is optional and can be enabled/disabled at will:

* acsf_sj, which provides integration with Scheduled Jobs functionality which
  is/may be available only after communication with your Acquia account manager.

The other modules contain interconnected ACSF functionality which is required
to all be enabled, even though it has historically been divided over various
submodules:

* acsf_duplication (providing the necessary scrubbing mechanisms on copies of
  a site's data that was duplicated in the ACSF Management Console)
* acsf_openid (providing the necessary functionality for login from the ACSF
  Management Console to work)
* acsf_pingdom (providing additional monitoring functionality for a subset of
  customers who have requested this)
* acsf_theme (containing functionality that enables the Drupal 7 theme builder
  which is distributed with the Gardens distribution, to communicate back to
  the ACSF Management Console)
* acsf_variables (providing a storage mechanism similar to Drupal 8 'state')

All modules share a single src/ directory (referenced in the main composer.json)
containing all of the classes.


Running acsf-init
-----------------

Your sites' codebase must be modified in order for the sites to function
properly on the Acquia Cloud Site Factory platform. (The most basic purpose of
this is to take over your codebase's sites.php file in order to point to the
correct site database & settings.php during early bootstrap; other purposes
include hooking into the staging / duplication process to modify data /
configuration in the target site.)

The command to do this is
```
drush --include=<PATH-TO-MODULE>/acsf_init acsf-init
```
Specify the -y flag to overwrite all acsf files in your codebase without
prompting. If you're running BLT, you may not need to run this command directly
but e.g. 'blt recipes:acsf:init:all' will take care of this.

Note that acsf_init is *not* a Drupal module that can be enabled; the acsf-init
command is a completely standalone script. This is intentional: the command
needs to be able to modify a site's codebase without any site databases being
present, or e.g. a Drupal codebase that's broken. This is why the --include
option is necessary to point to the directory containing this standalone drush
command.

### Verifying your codebase is correct

The acsf-init command needs to be re-run after every update of the acsf module,
to ensure the latest versions of the appropriate files are present in your
codebase. The command to verify that those files are present is:
```
drush --include=<PATH-TO-MODULE>/acsf_init acsf-init-verify
```
Acquia Cloud Site Factory will deny deploying any code which this command fails
to successfully verify.

Disabling OpenID login
----------------------

Acquia Cloud Site Factory for Drupal 7 was designed to always be able to log in
from the management console, for which it uses the OpenID protocol which works
with Drupal 7 Core. As mentioned earlier, the acsf_openid module cannot jut be
disabled.

Some customers want to stop this OpenID login from working anyway. To do this,
please implement a hook_system_info_alter in a custom module; something like:
```
function mymodule_system_info_alter(&$info, $file, $type) {
  if ($file->name == 'acsf_openid') {
    $info['dependencies'] = array();
  }
}
```
This should allow for disabling the acsf_openid module anyway. It means the
"Log in" buttons in the Management Console will not function anymore; no
other functionality should be affected.
